# dynmap2bluemap-markers

This small helper script can be used to convert a large amount of [POI markers](https://bluemap.bluecolored.de/wiki/customization/Markers.html#poi-markers) from [Dynmap](https://github.com/webbukkit/dynmap)'s format to the one [BlueMap](https://bluemap.bluecolored.de/) uses.


## Usage

```
usage: dynmap2bluemap - Markers [-h] [-m] [-n INDENT] [-i INPUT] [-o OUTPUT] [-p]

A small helper script converting the basic structure of Dynmap markers to the one of BlueMap.

options:
  -h, --help           show this help message and exit
  -m, --minimal        Choose wether the output shall be minimal or not (»beautified«)!
  -n, --indent INDENT  Specify the number of whitespaces to introduce for indentation in outputted json
  -i, --input INPUT    Specify the file to read Dynmap formatted input from
  -o, --output OUTPUT  Specify the file to write BlueMap formatted output to (if left, will be printed out on stdout)
  -p, --privacynerd    Change how labels are converted according to the PrivacynerdMC conventions; DO NOT USE if you don't know what you are doing.

© Benjamin Burkhardt, 2025
```


## Considerations

When using this script, you need to consider that it was originally written for my specific purpose (but with some general-purpose usage in mind) which was migrating all my markers from Dynmap (3 sets; using minzoom and some custom icons) to BlueMap.

Generally speaking, BlueMap offers some more options compared to Dynmap (such as a `detail` attribute which is the label shown on the map while the `label` attribute is only shown in lists, menus, etc.), and thus some standard values need to be set. There is little information loss when converting from Dynmap to BlueMap. Converted Markers have the `listed` attribute set to true by default. Also, the Dynmap zoom levels are mapped using the following mapping:

| Dynmap Zoom Level | BlueMap Height |
| ----------------- | -------------- |
| 0                 | 15000          |
| 1                 | 3000           |
| 2                 | 2000           |
| 3                 | 1300           |
| 4                 | 800            |
| 5                 | 500            |
| 6                 | 300            |

Using this table, given minzoom and maxzoom values are converted.

To make it short: all icon ids from the dynmap configuration are taken as the filename of a `.png` file lying in the `web/assets/custom-poi/` folder of the BlueMap installation (as when I migrated, all valid icons were `.png` as Dynmap requires it).

Some other very personal tweaks I made can be toggled on via the `-p` option, but otherwise everything should actually be quite general-purpose.


## For example

The following example (conversion without any extra parameters) shows pretty well how this script operates. For more info on whats possible

Dynmap: 

```yaml
%YAML 1.1
---
isSafe: true
sets:
    markers:
        hide: false
        circles: {
            }
        deficon: default
        areas: {
            }
        label: Markers
        markers:
            marker_1:
                world: world
                markup: false
                x: 0
                icon: spawn
                y: 64
                z: 0
                label: Spawn
                minzoom: 1
        lines: {
            }
        layerprio: 0
playersets: {
    }
```

Is being converted to BlueMap's JSON format:

```json
marker_set_0: {
    "label": "Markers",
    "toggleable": true,
    "default_hidden": false,
    "markers": {
        "marker_0": {
            "type": "poi",
            "label": "Spawn",
            "detail": "",
            "listed": true,
            "min-distance": 0,
            "max-distance": 3000,
            "position": {
                "x": 0,
                "y": 64,
                "z": 0
            },
            "icon": "assets/custom-poi/spawn.png",
            "anchor": {
                "x": 16,
                "y": 16
            }
        }
    }
}
```


## License

This project is licensed under GPL-3.0-or-later. See [LICENSE](LICENSE).
